==> python-tensorflow-cuda_1.3.1-1.debian.tar.xz: debian/configure-expect.sh <==
#!/usr/bin/expect

set timeout 30
set pythonversion [lindex $argv 0]
set gccoptions [lindex $argv 1]
set withcuda [lindex $argv 2]
set withopencl [lindex $argv 3]
set cudapath [lindex $argv 4]
set cudacap [lindex $argv 5]
set cudaver [lindex $argv 6]
set cudnnver [lindex $argv 7]
set withmkldnn [lindex $argv 8]
set mkldnnpath [lindex $argv 9]
set withopenmpi [lindex $argv 10]
set openmpipath [lindex $argv 11]
set pythonpath /usr/bin/python$pythonversion

if {[regexp "^2\." $pythonversion]} {
  set pythondistpath /usr/lib/python$pythonversion/dist-packages/
} else {
  set pythondistpath /usr/lib/python3/dist-packages/
}

spawn ./configure

expect "Please specify the location of python.*"
send "$pythonpath"
send "\r"

expect "Please input the desired Python library path to use.*"
send "$pythondistpath"
send "\r"

expect "Do you wish to build TensorFlow with MKL support*"
if {$withmkldnn == Yes} {
  send "Y\r"
  expect "Do you wish to download MKL LIB from the web*"
  send "N\r"
  expect "Please specify the location where MKL is installed.*"
  send "$mkldnnpath"
  send "\r"
} else {
  send "N\r"
}

expect "Please specify optimization flags to use during compilation when bazel option*"
send -- $gccoptions
send "\r"

expect "Do you wish to use jemalloc as the malloc implementation*"
send "Y\r"

expect "Do you wish to build TensorFlow with Google Cloud Platform support*"
send "Y\r"

expect "Do you wish to build TensorFlow with Hadoop File System support*"
send "Y\r"

# Marked as being experimental...
expect "Do you wish to build TensorFlow with the XLA just-in-time compiler*"
send "N\r"

expect "Do you wish to build TensorFlow with VERBS support*"
send "Y\r"

# For me it's not buildable. Bazel+computecpp always end up with a build error
# Tried several GCC or CLANG version, no luck.
expect "Do you wish to build TensorFlow with OpenCL support*"
if {$withopencl == Yes} {
  send "Y\r"
} else {
  send "N\r"
}

expect "Do you wish to build TensorFlow with CUDA support*"
if {$withcuda == Yes} {
  send "Y\r"
} else {
  send "N\r"
}

if {$withcuda == Yes} {
  expect "Do you want to use clang as CUDA compiler*"
  send "N\r"

  # Enable if you said Yes above
  #expect "Please specify which clang should be used as device and host compiler.*"
  #send "/usr/bin/gcc-4.9\r"

  expect "Please specify the CUDA SDK version you want to use*"
  send "$cudaver"
  send "\r"

  expect "Please specify the location where CUDA $cudaver toolkit is installed.*"
  send "$cudapath"
  send "\r"

  # Disable this if using clang
  expect "Please specify which gcc should be used by nvcc as the host compiler.*"
  send "/usr/bin/gcc-4.9\r"

  expect "Please specify the cuDNN version you want to use.*"
  send "$cudnnver" 
  send "\r"

  expect "Please specify the location where cuDNN $cudnnver library is installed.*"
  send "\r"

  expect "Please specify a list of comma-separated Cuda compute capabilities you want to build with.*"
  send "$cudacap"
  send "\r"
}

if {$withopencl == Yes} {
  expect "Please specify which C++ compiler should be used as the host C++ compiler.*"
  send "/usr/bin/g++-4.9\r"

  expect "Please specify which C compiler should be used as the host C compiler.*"
  send "/usr/bin/gcc-4.9\r"

  expect "Please specify the location where ComputeCpp for SYCL 1.2 is installed.*"
  send "/opt/computecpp\r"
}

expect "Do you wish to build TensorFlow with MPI support*"
if {$withopenmpi == Yes} {
  send "Y\r"
} else {
  send "N\r"
}

if {$withopenmpi == Yes} {
  expect "Please specify the MPI toolkit folder.*"
  send "$openmpipath"
  send "\r"
}

expect "Configuration finished"

==> python-tensorflow-cuda_1.4.1-1.debian.tar.xz: debian/configure-expect.sh <==
#!/usr/bin/expect

set timeout 30
set pythonversion [lindex $argv 0]
set gccoptions [lindex $argv 1]
set withcuda [lindex $argv 2]
set withopencl [lindex $argv 3]
set cudapath [lindex $argv 4]
set cudacap [lindex $argv 5]
set cudaver [lindex $argv 6]
set cudnnver [lindex $argv 7]
set withmkldnn [lindex $argv 8]
set mkldnnpath [lindex $argv 9]
set withopenmpi [lindex $argv 10]
set openmpipath [lindex $argv 11]
set pythonpath /usr/bin/python$pythonversion

if {[regexp "^2\." $pythonversion]} {
  set pythondistpath /usr/lib/python$pythonversion/dist-packages/
} else {
  set pythondistpath /usr/lib/python3/dist-packages/
}

spawn ./configure

expect "Please specify the location of python.*"
send "$pythonpath"
send "\r"

expect "Please input the desired Python library path to use.*"
send "$pythondistpath"
send "\r"

expect "Do you wish to build TensorFlow with jemalloc as malloc support*"
send "Y\r"

expect "Do you wish to build TensorFlow with Google Cloud Platform support*"
send "Y\r"

expect "Do you wish to build TensorFlow with Hadoop File System support*"
send "Y\r"

expect "Do you wish to build TensorFlow with Amazon S3 File System support*"
send "Y\r"

# Not marked as experimental anymore
expect "Do you wish to build TensorFlow with XLA JIT support*"
send "Y\r"

expect "Do you wish to build TensorFlow with GDR support*"
send "Y\r"

# Cannot be enabled without CUDA
# https://github.com/tensorflow/tensorflow/issues/14811
expect "Do you wish to build TensorFlow with VERBS support*"
if {$withcuda == Yes} {
  send "Y\r"
} else {
  send "N\r"
}

# Well that's gone with 1.4.0 for some reason.
#
#  'Add "--config=mkl" to your bazel command to build with MKL '
#  'support.\nPlease note that MKL on MacOS or windows is still not '
#  'supported.\nIf you would like to use a local MKL instead of '
#  'downloading, please set the environment variable \"TF_MKL_ROOT\" every '
#  'time before build.')
#
#expect "Do you wish to build TensorFlow with MKL support*"
#if {$withmkldnn == Yes} {
#  send "Y\r"
#  expect "Do you wish to download MKL LIB from the web*"
#  send "N\r"
#  expect "Please specify the location where MKL is installed.*"
#  send "$mkldnnpath"
#  send "\r"
#} else {
#  send "N\r"
#}

# For me it's not buildable. Bazel+computecpp always end up with a build error
# Tried several GCC or CLANG version, no luck.
expect "Do you wish to build TensorFlow with OpenCL support*"
if {$withopencl == Yes} {
  send "Y\r"
} else {
  send "N\r"
}

expect "Do you wish to build TensorFlow with CUDA support*"
if {$withcuda == Yes} {
  send "Y\r"
} else {
  send "N\r"
}

if {$withcuda == Yes} {
  expect "Please specify the CUDA SDK version you want to use*"
  send "$cudaver"
  send "\r"

  expect "Please specify the location where CUDA $cudaver toolkit is installed.*"
  send "$cudapath"
  send "\r"

  expect "Please specify the cuDNN version you want to use.*"
  send "$cudnnver" 
  send "\r"

  expect "Please specify the location where cuDNN $cudnnver library is installed.*"
  send "\r"

  expect "Please specify a list of comma-separated Cuda compute capabilities you want to build with.*"
  send "$cudacap"
  send "\r"

  expect "Do you want to use clang as CUDA compiler*"
  send "N\r"

  # Enable if you said Yes above
  #expect "Please specify which clang should be used as device and host compiler.*"
  #send "/usr/bin/gcc-4.9\r"

  # Disable this if using clang
  expect "Please specify which gcc should be used by nvcc as the host compiler.*"
  send "/usr/bin/gcc-4.9\r"
}

if {$withopencl == Yes} {
  expect "Please specify which C++ compiler should be used as the host C++ compiler.*"
  send "/usr/bin/g++-4.9\r"

  expect "Please specify which C compiler should be used as the host C compiler.*"
  send "/usr/bin/gcc-4.9\r"

  expect "Please specify the location where ComputeCpp for SYCL 1.2 is installed.*"
  send "/opt/computecpp\r"
}

# Cannot be enabled without CUDA
# https://github.com/tensorflow/tensorflow/issues/14811
expect "Do you wish to build TensorFlow with MPI support*"
#if {$withopenmpi == Yes} {
if {$withcuda == Yes && $withopenmpi == Yes} {
  send "Y\r"
} else {
  send "N\r"
}

#if {$withopenmpi == Yes} {
if {$withcuda == Yes && $withopenmpi == Yes} {
  expect "Please specify the MPI toolkit folder.*"
  send "$openmpipath"
  send "\r"
}

expect "Please specify optimization flags to use during compilation when bazel option*"
send -- $gccoptions
send "\r"

expect "Configuration finished"
